Inspectors
========================================================

Built-in Inspector
-----------------------------

.. toctree::
    :maxdepth: 2

    Inspector <base>
    DiscreteInspector <discrete>


Custom Inspectors Relevant
-----------------------------

.. toctree::
    :maxdepth: 2

    Extension hookspec <extension>
    InspectorManager <manager>
